/*
 *  $Id: gwystock.h 25436 2023-06-14 15:32:55Z yeti-dn $
 *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef __GWY_STOCK_H__
#define __GWY_STOCK_H__

#include <glib.h>

G_BEGIN_DECLS

/* The following generated part is updated by running utils/stockgen.py */

/* @@@ GENERATED STOCK LIST BEGIN @@@ */
#define GWY_STOCK_3D_BASE                        "gwy_3d_base"
#define GWY_STOCK_ARITHMETIC                     "gwy_arithmetic"
#define GWY_STOCK_BINNING                        "gwy_binning"
#define GWY_STOCK_BOLD                           "gwy_bold"
#define GWY_STOCK_CANTILEVER                     "gwy_cantilever"
#define GWY_STOCK_COLOR_RANGE                    "gwy_color_range"
#define GWY_STOCK_COLOR_RANGE_ADAPTIVE           "gwy_color_range_adaptive"
#define GWY_STOCK_COLOR_RANGE_AUTO               "gwy_color_range_auto"
#define GWY_STOCK_COLOR_RANGE_FIXED              "gwy_color_range_fixed"
#define GWY_STOCK_COLOR_RANGE_FULL               "gwy_color_range_full"
#define GWY_STOCK_CONVOLUTION                    "gwy_convolution"
#define GWY_STOCK_CONVOLVE                       "gwy_convolve"
#define GWY_STOCK_CORRECT_AFFINE                 "gwy_correct_affine"
#define GWY_STOCK_CORRELATION_LENGTH             "gwy_correlation_length"
#define GWY_STOCK_CORRELATION_MASK               "gwy_correlation_mask"
#define GWY_STOCK_CROP                           "gwy_crop"
#define GWY_STOCK_CROSS_PROFILE                  "gwy_cross_profile"
#define GWY_STOCK_CURVATURE                      "gwy_curvature"
#define GWY_STOCK_CWT                            "gwy_cwt"
#define GWY_STOCK_DATA_MEASURE                   "gwy_data_measure"
#define GWY_STOCK_DECONVOLVE                     "gwy_deconvolve"
#define GWY_STOCK_DISCONNECTED                   "gwy_disconnected"
#define GWY_STOCK_DISPLACEMENT_FIELD             "gwy_displacement_field"
#define GWY_STOCK_DISTANCE                       "gwy_distance"
#define GWY_STOCK_DISTANCE_TRANSFORM             "gwy_distance_transform"
#define GWY_STOCK_DISTRIBUTION_ANGLE             "gwy_distribution_angle"
#define GWY_STOCK_DISTRIBUTION_SLOPE             "gwy_distribution_slope"
#define GWY_STOCK_DRIFT                          "gwy_drift"
#define GWY_STOCK_DWT                            "gwy_dwt"
#define GWY_STOCK_EDGE                           "gwy_edge"
#define GWY_STOCK_ENFORCE_DISTRIBUTION           "gwy_enforce_distribution"
#define GWY_STOCK_ENTROPY                        "gwy_entropy"
#define GWY_STOCK_EXTEND                         "gwy_extend"
#define GWY_STOCK_EXTRACT_PATH                   "gwy_extract_path"
#define GWY_STOCK_FACET_ANALYSIS                 "gwy_facet_analysis"
#define GWY_STOCK_FACET_LEVEL                    "gwy_facet_level"
#define GWY_STOCK_FACET_MEASURE                  "gwy_facet_measure"
#define GWY_STOCK_FAVOURITE                      "gwy_favourite"
#define GWY_STOCK_FFT                            "gwy_fft"
#define GWY_STOCK_FFT_2D                         "gwy_fft_2d"
#define GWY_STOCK_FFT_FILTER_1D                  "gwy_fft_filter_1d"
#define GWY_STOCK_FFT_FILTER_2D                  "gwy_fft_filter_2d"
#define GWY_STOCK_FILTER                         "gwy_filter"
#define GWY_STOCK_FIND_PEAKS                     "gwy_find_peaks"
#define GWY_STOCK_FIT_SHAPE                      "gwy_fit_shape"
#define GWY_STOCK_FIX_ZERO                       "gwy_fix_zero"
#define GWY_STOCK_FLIP_DIAGONALLY                "gwy_flip_diagonally"
#define GWY_STOCK_FLIP_HORIZONTALLY              "gwy_flip_horizontally"
#define GWY_STOCK_FLIP_VERTICALLY                "gwy_flip_vertically"
#define GWY_STOCK_FRACTAL                        "gwy_fractal"
#define GWY_STOCK_FRACTAL_CORRECTION             "gwy_fractal_correction"
#define GWY_STOCK_FRACTAL_MEASURE                "gwy_fractal_measure"
#define GWY_STOCK_FREQUENCY_SPLIT                "gwy_frequency_split"
#define GWY_STOCK_GL_MATERIAL                    "gwy_gl_material"
#define GWY_STOCK_GRADIENT_HORIZONTAL            "gwy_gradient_horizontal"
#define GWY_STOCK_GRADIENT_VERTICAL              "gwy_gradient_vertical"
#define GWY_STOCK_GRAIN_BOUNDING_BOX             "gwy_grain_bounding_box"
#define GWY_STOCK_GRAIN_CORRELATION              "gwy_grain_correlation"
#define GWY_STOCK_GRAIN_EXSCRIBED_CIRCLE         "gwy_grain_exscribed_circle"
#define GWY_STOCK_GRAIN_INSCRIBED_BOX            "gwy_grain_inscribed_box"
#define GWY_STOCK_GRAIN_INSCRIBED_CIRCLE         "gwy_grain_inscribed_circle"
#define GWY_STOCK_GRAINS                         "gwy_grains"
#define GWY_STOCK_GRAINS_EDGE                    "gwy_grains_edge"
#define GWY_STOCK_GRAINS_EDGE_REMOVE             "gwy_grains_edge_remove"
#define GWY_STOCK_GRAINS_GRAPH                   "gwy_grains_graph"
#define GWY_STOCK_GRAINS_MEASURE                 "gwy_grains_measure"
#define GWY_STOCK_GRAINS_OTSU                    "gwy_grains_otsu"
#define GWY_STOCK_GRAINS_REMOVE                  "gwy_grains_remove"
#define GWY_STOCK_GRAINS_STATISTICS              "gwy_grains_statistics"
#define GWY_STOCK_GRAINS_WATER                   "gwy_grains_water"
#define GWY_STOCK_GRAPH                          "gwy_graph"
#define GWY_STOCK_GRAPH_ALIGN                    "gwy_graph_align"
#define GWY_STOCK_GRAPH_CUT                      "gwy_graph_cut"
#define GWY_STOCK_GRAPH_DOS                      "gwy_graph_dos"
#define GWY_STOCK_GRAPH_EXPORT_ASCII             "gwy_graph_export_ascii"
#define GWY_STOCK_GRAPH_EXPORT_PNG               "gwy_graph_export_png"
#define GWY_STOCK_GRAPH_EXPORT_VECTOR            "gwy_graph_export_vector"
#define GWY_STOCK_GRAPH_FD                       "gwy_graph_fd"
#define GWY_STOCK_GRAPH_FILTER                   "gwy_graph_filter"
#define GWY_STOCK_GRAPH_FUNCTION                 "gwy_graph_function"
#define GWY_STOCK_GRAPH_HALFGAUSS                "gwy_graph_halfgauss"
#define GWY_STOCK_GRAPH_LEVEL                    "gwy_graph_level"
#define GWY_STOCK_GRAPH_MEASURE                  "gwy_graph_measure"
#define GWY_STOCK_GRAPH_PALETTE                  "gwy_graph_palette"
#define GWY_STOCK_GRAPH_PERIOD_MEASURE           "gwy_graph_period_measure"
#define GWY_STOCK_GRAPH_POINTER                  "gwy_graph_pointer"
#define GWY_STOCK_GRAPH_RULER                    "gwy_graph_ruler"
#define GWY_STOCK_GRAPH_STATISTICS               "gwy_graph_statistics"
#define GWY_STOCK_GRAPH_TERRACE_MEASURE          "gwy_graph_terrace_measure"
#define GWY_STOCK_GRAPH_VERTICAL                 "gwy_graph_vertical"
#define GWY_STOCK_GRAPH_ZOOM_FIT                 "gwy_graph_zoom_fit"
#define GWY_STOCK_GRAPH_ZOOM_IN                  "gwy_graph_zoom_in"
#define GWY_STOCK_GRAPH_ZOOM_OUT                 "gwy_graph_zoom_out"
#define GWY_STOCK_GWYDDION                       "gwy_gwyddion"
#define GWY_STOCK_HOLD_SELECTION_CLEAR           "gwy_hold_selection_clear"
#define GWY_STOCK_HOLD_SELECTION_REPLACE         "gwy_hold_selection_replace"
#define GWY_STOCK_HOUGH                          "gwy_hough"
#define GWY_STOCK_IMAGE_RELATION                 "gwy_image_relation"
#define GWY_STOCK_IMMERSE                        "gwy_immerse"
#define GWY_STOCK_ISO_ROUGHNESS                  "gwy_iso_roughness"
#define GWY_STOCK_ITALIC                         "gwy_italic"
#define GWY_STOCK_LESS                           "gwy_less"
#define GWY_STOCK_LEVEL                          "gwy_level"
#define GWY_STOCK_LEVEL_FLATTEN_BASE             "gwy_level_flatten_base"
#define GWY_STOCK_LEVEL_MEDIAN                   "gwy_level_median"
#define GWY_STOCK_LEVEL_TRIANGLE                 "gwy_level_triangle"
#define GWY_STOCK_LIGHT_ROTATE                   "gwy_light_rotate"
#define GWY_STOCK_LIMIT_RANGE                    "gwy_limit_range"
#define GWY_STOCK_LINE_LEVEL                     "gwy_line_level"
#define GWY_STOCK_LOAD_DEBUG                     "gwy_load_debug"
#define GWY_STOCK_LOAD_INFO                      "gwy_load_info"
#define GWY_STOCK_LOAD_WARNING                   "gwy_load_warning"
#define GWY_STOCK_LOCAL_SLOPE                    "gwy_local_slope"
#define GWY_STOCK_LOGSCALE_HORIZONTAL            "gwy_logscale_horizontal"
#define GWY_STOCK_LOGSCALE_VERTICAL              "gwy_logscale_vertical"
#define GWY_STOCK_MARK_OUTLIERS                  "gwy_mark_outliers"
#define GWY_STOCK_MARK_SCARS                     "gwy_mark_scars"
#define GWY_STOCK_MARK_WITH                      "gwy_mark_with"
#define GWY_STOCK_MASK                           "gwy_mask"
#define GWY_STOCK_MASK_ADD                       "gwy_mask_add"
#define GWY_STOCK_MASK_CIRCLE                    "gwy_mask_circle"
#define GWY_STOCK_MASK_CIRCLE_EXCLUSIVE          "gwy_mask_circle_exclusive"
#define GWY_STOCK_MASK_CIRCLE_INCLUSIVE          "gwy_mask_circle_inclusive"
#define GWY_STOCK_MASK_DISTRIBUTE                "gwy_mask_distribute"
#define GWY_STOCK_MASK_EDITOR                    "gwy_mask_editor"
#define GWY_STOCK_MASK_EXCLUDE                   "gwy_mask_exclude"
#define GWY_STOCK_MASK_EXCLUDE_CIRCLE            "gwy_mask_exclude_circle"
#define GWY_STOCK_MASK_EXTRACT                   "gwy_mask_extract"
#define GWY_STOCK_MASK_FILL_DRAW                 "gwy_mask_fill_draw"
#define GWY_STOCK_MASK_FILL_ERASE                "gwy_mask_fill_erase"
#define GWY_STOCK_MASK_GROW                      "gwy_mask_grow"
#define GWY_STOCK_MASK_INTERSECT                 "gwy_mask_intersect"
#define GWY_STOCK_MASK_INVERT                    "gwy_mask_invert"
#define GWY_STOCK_MASK_LINE                      "gwy_mask_line"
#define GWY_STOCK_MASK_MORPH                     "gwy_mask_morph"
#define GWY_STOCK_MASK_NOISIFY                   "gwy_mask_noisify"
#define GWY_STOCK_MASK_PAINT_DRAW                "gwy_mask_paint_draw"
#define GWY_STOCK_MASK_PAINT_ERASE               "gwy_mask_paint_erase"
#define GWY_STOCK_MASK_RECT_EXCLUSIVE            "gwy_mask_rect_exclusive"
#define GWY_STOCK_MASK_RECT_INCLUSIVE            "gwy_mask_rect_inclusive"
#define GWY_STOCK_MASK_REMOVE                    "gwy_mask_remove"
#define GWY_STOCK_MASK_SET                       "gwy_mask_set"
#define GWY_STOCK_MASK_SHIFT                     "gwy_mask_shift"
#define GWY_STOCK_MASK_SHRINK                    "gwy_mask_shrink"
#define GWY_STOCK_MASK_SUBTRACT                  "gwy_mask_subtract"
#define GWY_STOCK_MASK_THIN                      "gwy_mask_thin"
#define GWY_STOCK_MEASURE_LATTICE                "gwy_measure_lattice"
#define GWY_STOCK_MERGE                          "gwy_merge"
#define GWY_STOCK_MFM_CONVERT_TO_FORCE           "gwy_mfm_convert_to_force"
#define GWY_STOCK_MFM_CURRENT_LINE               "gwy_mfm_current_line"
#define GWY_STOCK_MFM_FIELD_FIND_SHIFT           "gwy_mfm_field_find_shift"
#define GWY_STOCK_MFM_FIELD_SHIFT                "gwy_mfm_field_shift"
#define GWY_STOCK_MFM_PARALLEL                   "gwy_mfm_parallel"
#define GWY_STOCK_MFM_PERPENDICULAR              "gwy_mfm_perpendicular"
#define GWY_STOCK_MORE                           "gwy_more"
#define GWY_STOCK_MUTUAL_CROP                    "gwy_mutual_crop"
#define GWY_STOCK_NEURAL_APPLY                   "gwy_neural_apply"
#define GWY_STOCK_NEURAL_TRAIN                   "gwy_neural_train"
#define GWY_STOCK_NEXT                           "gwy_next"
#define GWY_STOCK_NULL_OFFSETS                   "gwy_null_offsets"
#define GWY_STOCK_PALETTES                       "gwy_palettes"
#define GWY_STOCK_PATH_LEVEL                     "gwy_path_level"
#define GWY_STOCK_PERSPECTIVE_DISTORT            "gwy_perspective_distort"
#define GWY_STOCK_POINTER_MEASURE                "gwy_pointer_measure"
#define GWY_STOCK_POLY_DISTORT                   "gwy_poly_distort"
#define GWY_STOCK_POLYNOM                        "gwy_polynom"
#define GWY_STOCK_POLYNOM_LEVEL                  "gwy_polynom_level"
#define GWY_STOCK_PREVIOUS                       "gwy_previous"
#define GWY_STOCK_PROFILE                        "gwy_profile"
#define GWY_STOCK_PROFILE_MULTIPLE               "gwy_profile_multiple"
#define GWY_STOCK_PSDF_LOG_PHI                   "gwy_psdf_log_phi"
#define GWY_STOCK_PSDF_SECTION                   "gwy_psdf_section"
#define GWY_STOCK_PYGWY                          "gwy_pygwy"
#define GWY_STOCK_RADIAL_PROFILE                 "gwy_radial_profile"
#define GWY_STOCK_RANK_FILTER                    "gwy_rank_filter"
#define GWY_STOCK_RASTERIZE                      "gwy_rasterize"
#define GWY_STOCK_REMOVE_UNDER_MASK              "gwy_remove_under_mask"
#define GWY_STOCK_REVOLVE_ARC                    "gwy_revolve_arc"
#define GWY_STOCK_REVOLVE_SPHERE                 "gwy_revolve_sphere"
#define GWY_STOCK_ROTATE                         "gwy_rotate"
#define GWY_STOCK_ROTATE_180                     "gwy_rotate_180"
#define GWY_STOCK_ROTATE_3D                      "gwy_rotate_3d"
#define GWY_STOCK_ROTATE_90_CCW                  "gwy_rotate_90_ccw"
#define GWY_STOCK_ROTATE_90_CW                   "gwy_rotate_90_cw"
#define GWY_STOCK_SCALE                          "gwy_scale"
#define GWY_STOCK_SCALE_HORIZONTALLY             "gwy_scale_horizontally"
#define GWY_STOCK_SCALE_VERTICALLY               "gwy_scale_vertically"
#define GWY_STOCK_SCARS                          "gwy_scars"
#define GWY_STOCK_SCIENTIFIC_NUMBER_FORMAT       "gwy_scientific_number_format"
#define GWY_STOCK_SELECTIONS                     "gwy_selections"
#define GWY_STOCK_SHADER                         "gwy_shader"
#define GWY_STOCK_SPECTRUM                       "gwy_spectrum"
#define GWY_STOCK_SPOT_REMOVE                    "gwy_spot_remove"
#define GWY_STOCK_SQUARE_SAMPLES                 "gwy_square_samples"
#define GWY_STOCK_STAT_QUANTITIES                "gwy_stat_quantities"
#define GWY_STOCK_STITCH                         "gwy_stitch"
#define GWY_STOCK_STRAIGHTEN_PATH                "gwy_straighten_path"
#define GWY_STOCK_SUBSCRIPT                      "gwy_subscript"
#define GWY_STOCK_SUPERSCRIPT                    "gwy_superscript"
#define GWY_STOCK_SYNTHETIC_ANNEAL               "gwy_synthetic_anneal"
#define GWY_STOCK_SYNTHETIC_BALLISTIC_DEPOSITION "gwy_synthetic_ballistic_deposition"
#define GWY_STOCK_SYNTHETIC_BROWNIAN_MOTION      "gwy_synthetic_brownian_motion"
#define GWY_STOCK_SYNTHETIC_COLUMNAR             "gwy_synthetic_columnar"
#define GWY_STOCK_SYNTHETIC_DIFFUSION            "gwy_synthetic_diffusion"
#define GWY_STOCK_SYNTHETIC_DISCS                "gwy_synthetic_discs"
#define GWY_STOCK_SYNTHETIC_DOMAINS              "gwy_synthetic_domains"
#define GWY_STOCK_SYNTHETIC_DUNES                "gwy_synthetic_dunes"
#define GWY_STOCK_SYNTHETIC_FIBRES               "gwy_synthetic_fibres"
#define GWY_STOCK_SYNTHETIC_LATTICE              "gwy_synthetic_lattice"
#define GWY_STOCK_SYNTHETIC_LINE_NOISE           "gwy_synthetic_line_noise"
#define GWY_STOCK_SYNTHETIC_NOISE                "gwy_synthetic_noise"
#define GWY_STOCK_SYNTHETIC_OBJECTS              "gwy_synthetic_objects"
#define GWY_STOCK_SYNTHETIC_PARTICLES            "gwy_synthetic_particles"
#define GWY_STOCK_SYNTHETIC_PATTERN              "gwy_synthetic_pattern"
#define GWY_STOCK_SYNTHETIC_PHASES               "gwy_synthetic_phases"
#define GWY_STOCK_SYNTHETIC_PILEUP               "gwy_synthetic_pileup"
#define GWY_STOCK_SYNTHETIC_PLATEAUS             "gwy_synthetic_plateaus"
#define GWY_STOCK_SYNTHETIC_SPECTRAL             "gwy_synthetic_spectral"
#define GWY_STOCK_SYNTHETIC_TURING_PATTERN       "gwy_synthetic_turing_pattern"
#define GWY_STOCK_SYNTHETIC_WAVES                "gwy_synthetic_waves"
#define GWY_STOCK_TERRACE_MEASURE                "gwy_terrace_measure"
#define GWY_STOCK_TILT                           "gwy_tilt"
#define GWY_STOCK_TIP_DILATION                   "gwy_tip_dilation"
#define GWY_STOCK_TIP_EROSION                    "gwy_tip_erosion"
#define GWY_STOCK_TIP_ESTIMATION                 "gwy_tip_estimation"
#define GWY_STOCK_TIP_INDENT_ANALYZE             "gwy_tip_indent_analyze"
#define GWY_STOCK_TIP_LATERAL_FORCE              "gwy_tip_lateral_force"
#define GWY_STOCK_TIP_MAP                        "gwy_tip_map"
#define GWY_STOCK_TIP_MODEL                      "gwy_tip_model"
#define GWY_STOCK_TIP_PID                        "gwy_tip_pid"
#define GWY_STOCK_UNROTATE                       "gwy_unrotate"
#define GWY_STOCK_VALUE_INVERT                   "gwy_value_invert"
#define GWY_STOCK_VOLUME                         "gwy_volume"
#define GWY_STOCK_VOLUME_ARITHMETIC              "gwy_volume_arithmetic"
#define GWY_STOCK_VOLUME_CALIBRATE               "gwy_volume_calibrate"
#define GWY_STOCK_VOLUME_DIMENSIONS              "gwy_volume_dimensions"
#define GWY_STOCK_VOLUME_FD                      "gwy_volume_fd"
#define GWY_STOCK_VOLUME_INVERT                  "gwy_volume_invert"
#define GWY_STOCK_VOLUME_KMEANS                  "gwy_volume_kmeans"
#define GWY_STOCK_VOLUME_KMEDIANS                "gwy_volume_kmedians"
#define GWY_STOCK_VOLUME_LINE_STATS              "gwy_volume_line_stats"
#define GWY_STOCK_VOLUME_PLANE_STATS             "gwy_volume_plane_stats"
#define GWY_STOCK_VOLUME_SLICE                   "gwy_volume_slice"
#define GWY_STOCK_VOLUME_SWAP_AXES               "gwy_volume_swap_axes"
#define GWY_STOCK_VOLUMIZE                       "gwy_volumize"
#define GWY_STOCK_VOLUMIZE_LAYERS                "gwy_volumize_layers"
#define GWY_STOCK_WRAP_VALUE                     "gwy_wrap_value"
#define GWY_STOCK_XY_DENOISE                     "gwy_xy_denoise"
#define GWY_STOCK_XYZIZE                         "gwy_xyzize"
#define GWY_STOCK_ZERO_MAXIMUM                   "gwy_zero_maximum"
#define GWY_STOCK_ZERO_MEAN                      "gwy_zero_mean"
#define GWY_STOCK_ZERO_UNDER_MASK                "gwy_zero_under_mask"
#define GWY_STOCK_ZOOM_1_1                       "gwy_zoom_1_1"
#define GWY_STOCK_ZOOM_FIT                       "gwy_zoom_fit"
#define GWY_STOCK_ZOOM_IN                        "gwy_zoom_in"
#define GWY_STOCK_ZOOM_OUT                       "gwy_zoom_out"
/* @@@ GENERATED STOCK LIST END @@@ */

#define GWY_ICON_SIZE_ABOUT "gwy-about"

void gwy_stock_register_stock_items(void);

G_END_DECLS

#endif /* __GWY_STOCK_H__ */

/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */

